/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.search.engine.adapter.document;

import aQute.bnd.annotation.ProviderType;

import com.liferay.portal.kernel.search.Document;

import java.util.function.Consumer;

/**
 * @author Michael C. Han
 */
@ProviderType
public class UpdateDocumentRequest
	implements BulkableDocumentRequest<UpdateDocumentRequest>,
			   DocumentRequest<UpdateDocumentResponse> {

	public UpdateDocumentRequest(
		String indexName, String uid, Document document) {

		_indexName = indexName;
		_uid = uid;
		_document = document;
	}

	@Override
	public void accept(Consumer<UpdateDocumentRequest> consumer) {
		consumer.accept(this);
	}

	@Override
	public UpdateDocumentResponse accept(
		DocumentRequestExecutor documentRequestExecutor) {

		return documentRequestExecutor.executeDocumentRequest(this);
	}

	public Document getDocument() {
		return _document;
	}

	public String getIndexName() {
		return _indexName;
	}

	public String getUid() {
		return _uid;
	}

	public boolean isRefresh() {
		return _refresh;
	}

	public void setRefresh(boolean refresh) {
		_refresh = refresh;
	}

	private final Document _document;
	private final String _indexName;
	private boolean _refresh;
	private final String _uid;

}